/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.service.common;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.common.UserSession;
import com.hack23.cia.service.api.application.ApplicationManager;
import com.hack23.cia.service.api.application.ApplicationRequest;
import com.hack23.cia.service.api.common.ServiceResponse;
import com.hack23.cia.testfoundation.AbstractFunctionalIntegrationTransactionalTest;

/**
 * The Class AbstractServiceRequestFunctionalIntegrationTest.
 */
public abstract class AbstractServiceRequestFunctionalIntegrationTest extends
        AbstractFunctionalIntegrationTransactionalTest {

    /** The application manager. */
    @Autowired
    @Qualifier("applicationManager")
    protected ApplicationManager applicationManager;

    /** The initial user session. */
    protected UserSession initialUserSession;

    /** The response user session. */
    protected UserSession responseUserSession;
    
    /** The service response. */
    protected ServiceResponse serviceResponse;

    /**
     * Creates the initial user session.
     *
     * @throws Exception the exception
     */
    public final void createInitialUserSession() throws Exception {
        ApplicationRequest applicationRequest = TestRequestFactory
                .createApplicationRequestSwedishUser();
        this.initialUserSession = this.applicationManager.service(
                applicationRequest).getUserSessionDTO().getUserSession();
    }
    
    /**
     * Setup database pre condition.
     *
     * @throws Exception the exception
     */
    @BeforeTransaction
    public abstract void setupDatabasePreCondition() throws Exception;

    /**
     * Verify database post condition.
     *
     * @throws Exception the exception
     */
    @AfterTransaction
    public abstract void verifyDatabasePostCondition() throws Exception;

}
