/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.service.user;

import junit.framework.Assert;

import org.junit.Test;
import org.springframework.security.authentication.encoding.Md5PasswordEncoder;
import org.springframework.security.authentication.encoding.PasswordEncoder;
import org.springframework.test.context.transaction.AfterTransaction;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.common.User.UserRole;
import com.hack23.cia.model.application.impl.user.UserAccountActionEvent;
import com.hack23.cia.service.api.common.ServiceResponse.ServiceResult;
import com.hack23.cia.service.api.user.LoginRequest;

/**
 * The Class LoginRequestSuccessFullTest.
 */
public class LoginRequestSuccessFullTest extends AbstractUserRequestTest {

    /** The password encoder. */
    private final PasswordEncoder passwordEncoder = new Md5PasswordEncoder();

    /**
     * Instantiates a new login request success full test.
     */
    public LoginRequestSuccessFullTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Login request succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void loginRequestSucceeds() throws Exception {
        LoginRequest loginRequest = new LoginRequest(this.initialUserSession
                .getId(),UserAccountActionEvent.Operation.Process_login, "sysop", passwordEncoder.encodePassword("equalrites",
                null));
        serviceResponse = this.applicationManager.service(loginRequest);
        Assert.assertEquals(ServiceResult.SUCCESS, serviceResponse.getResult());
        Assert.assertEquals(UserRole.ADMIN, serviceResponse.getUserSessionDTO().getUserSession()
                .getUser().getUserRole());
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.service.common.AbstractServiceRequestFunctionalIntegrationTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.service.common.AbstractServiceRequestFunctionalIntegrationTest#verifyDatabasePostCondition()
     */
    @Override
    @AfterTransaction
    public void verifyDatabasePostCondition() throws Exception {
    }
}
