/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.web.action.admin.ConfigureAgencyAction;
import com.hack23.cia.web.viewfactory.api.admin.AgencyModelAndView;

/**
 * The Class ConfigureAgencyActionActionSuccessTest.
 */
public class ConfigureAgencyActionActionSuccessTest extends
        AbstractFunctionalAdminActionTest {

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(AgencyModelAndView.class);

    /**
     * Instantiates a new configure agency action action success test.
     */
    public ConfigureAgencyActionActionSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Configure agency action succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void configureAgencyActionSucceeds() throws Exception {
        ConfigureAgencyAction action = new ConfigureAgencyAction();
        this.frontController.handleAction(action);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        prepareLoggedInAdminUser();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        AgencyModelAndView modelAndView = (AgencyModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(AgencyModelAndView.AgencyViewSpecification.ConfigureAgencyView, modelAndView.getAgencyViewSpecification());
        Assert.assertEquals(AgencyModelAndView.AgencyViewSpecification.ConfigureAgencyView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getAgency());        
    }        


}
