/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.admin;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionStatus;
import org.springframework.transaction.support.DefaultTransactionDefinition;

import com.hack23.cia.model.application.impl.admin.PortalActionEvent;
import com.hack23.cia.model.application.impl.common.Portal;
import com.hack23.cia.web.action.admin.PortalAction;
import com.hack23.cia.web.viewfactory.api.admin.PortalModelAndView;

/**
 * The Class PortalActionUpdateSuccessTest.
 */
public class PortalActionUpdateSuccessTest extends
        AbstractFunctionalAdminActionTest {
    
    /** The created portal. */
    private Portal createdPortal;

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(PortalModelAndView.class);

    /**
     * Instantiates a new portal action update success test.
     */
    public PortalActionUpdateSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Portal action update succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void portalActionUpdateSucceeds() throws Exception {
        Portal portalDto = new Portal();
        portalDto.setId(createdPortal.getId());
        portalDto.setName(createdPortal.getName());
        portalDto.setTitleDescription(createdPortal.getTitleDescription());
        portalDto.setAgency(createdPortal.getAgency());
        portalDto.setMatchesUrl("CHanged value");
        
        PortalAction action = new PortalAction(PortalActionEvent.Operation.Update,portalDto);
        this.frontController.handleAction(action);
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        cleanOutOldTestData();
        
        TransactionDefinition transactionDefinition = new DefaultTransactionDefinition(TransactionDefinition.PROPAGATION_REQUIRES_NEW);
        
        TransactionStatus transaction = transactionManager.getTransaction(transactionDefinition);
        prepareLoggedInAdminUser();
        createdPortal = createPortal();         
        transactionManager.commit(transaction);
    }


    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService)
                        .processView(
                                with(modelAndViewMatcher));
            }
        });
     }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        PortalModelAndView modelAndView = (PortalModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(PortalModelAndView.PortalViewSpecification.ConfigurePortalView, modelAndView.getPortalViewSpecification());
        Assert.assertEquals(PortalModelAndView.PortalViewSpecification.ConfigurePortalView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getPortal()); 
        
    }


    
}
