/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.application;

import java.util.ArrayList;
import java.util.List;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.annotation.NotTransactional;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest;
import com.hack23.cia.web.action.application.ApplicationAction;
import com.hack23.cia.web.viewfactory.api.application.ApplicationModelAndView;
import com.hack23.cia.web.viewfactory.api.common.ErrorMessageModelAndView;

/**
 * The Class ApplicationActionFailureTest.
 */
public class ApplicationActionFailureTest extends
        AbstractFunctionalActionWithoutViewFactoryTest {

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(ErrorMessageModelAndView.class);

    /**
     * Instantiates a new application action failure test.
     */
    public ApplicationActionFailureTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Application action fail with view factory exception.
     *
     * @throws Exception the exception
     */
    @Test
    @NotTransactional 
    public final void applicationActionFailWithViewFactoryException() throws Exception {
        List<String> argList = new ArrayList<String>();
        argList
                .add("HEADER_USER-AGENT=Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.0.12) Gecko/2009070811 Ubuntu/9.04 (jaunty) Firefox/3.0.12");
        argList.add("HEADER_ACCEPT-LANGUAGE=xx-xx,xx;q=0.7,sv;q=0.3");
        argList.add("HEADER_COOKIE=JSESSIONID=1ugmg9f4tsmvw");
        argList.add("HEADER_HOST=localhost:9090");
        argList.add("CLIENT_INFO_ADDRESS=0:0:0:0:0:0:0:1");
        argList.add("CLIENT_INFO_HOST=0:0:0:0:0:0:0:1");
        argList.add("CLIENT_INFO_USER=null");

        String[] args = new String[argList.size()];
        argList.toArray(args);

        ApplicationAction action = new ApplicationAction(null, args);
        this.frontController.handleAction(action);
    }


    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(new ModelAndViewMatcher(
                                ApplicationModelAndView.class)));
                will(throwException(new RuntimeException()));
            }
        });  
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(modelAndViewMatcher));
            }
        });          
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        ErrorMessageModelAndView modelAndView = (ErrorMessageModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(ErrorMessageModelAndView.ErrorViewSpecification.ErrorMessageView, modelAndView.getErrorViewSpecification());
        Assert.assertEquals(ErrorMessageModelAndView.ErrorViewSpecification.ErrorMessageView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getErrorMessage());        
    }        

}
