/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.web.action.common.AbstractAction;
import com.hack23.cia.web.action.common.ActionCategory;
import com.hack23.cia.web.action.common.ControllerAction;
import com.hack23.cia.web.viewfactory.api.common.ErrorMessageModelAndView;

/**
 * The Class UnknownActionFailureTest.
 */
public class UnknownActionFailureTest extends
        AbstractFunctionalActionWithoutViewFactoryTest {

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(ErrorMessageModelAndView.class);

    /**
     * Instantiates a new unknown action failure test.
     */
    public UnknownActionFailureTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /**
     * Application error action succeeds.
     *
     * @throws Exception the exception
     */
    @SuppressWarnings("static-access")
    @Test
    public final void applicationErrorActionSucceeds() throws Exception {
        ControllerAction action = new AbstractAction(ActionCategory.Application.Application) {

            /**
             * 
             */
            private static final long serialVersionUID = 1L;
            
        };
        this.frontController.handleAction(action);
    }


    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        createInitialUserSession();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(modelAndViewMatcher));
            }
        });        
    }
    
    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        ErrorMessageModelAndView modelAndView = (ErrorMessageModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(ErrorMessageModelAndView.ErrorViewSpecification.ErrorMessageView, modelAndView.getErrorViewSpecification());
        Assert.assertEquals(ErrorMessageModelAndView.ErrorViewSpecification.ErrorMessageView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getErrorMessage());        
    }        
}
