/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.functionalintegrationtest.scenarios.web.controller.user;

import junit.framework.Assert;

import org.jmock.Expectations;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.springframework.test.context.transaction.BeforeTransaction;

import com.hack23.cia.model.application.impl.user.ExternalUrlActionEvent;
import com.hack23.cia.web.action.user.ExternalUrlAction;
import com.hack23.cia.web.viewfactory.api.user.UrlModelAndView;

/**
 * The Class ExternalUrlShowProjectInformationActionSuccessTest.
 */
public class ExternalUrlShowProjectInformationActionSuccessTest extends
AbstractFunctionalUserActionTest {

    /** The model and view matcher. */
    private ModelAndViewMatcher modelAndViewMatcher = new ModelAndViewMatcher(UrlModelAndView.class);

    /**
     * Instantiates a new external url show project information action success test.
     */
    public ExternalUrlShowProjectInformationActionSuccessTest() {
        super();
        this.testScenarioName = this.getClass().getSimpleName();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.user.AbstractFunctionalUserActionTest#setupDatabasePreCondition()
     */
    @Override
    @BeforeTransaction
    public void setupDatabasePreCondition() throws Exception {
        createInitialUserSession();
    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#setupExpectedModelAndView()
     */
    @Override
    @Before
    public void setupExpectedModelAndView() throws Exception {
        context.checking(new Expectations() {
            {
                one(viewFactoryService).processView(
                        with(modelAndViewMatcher));
            }
        });
        
    }


    /**
     * Show project information action succeeds.
     *
     * @throws Exception the exception
     */
    @Test
    public final void showProjectInformationActionSucceeds() throws Exception {
        ExternalUrlAction action = new ExternalUrlAction(
                ExternalUrlActionEvent.Operation.ShowProjectInformation);
        this.frontController.handleAction(action);

    }

    /* (non-Javadoc)
     * @see com.hack23.cia.functionalintegrationtest.scenarios.web.controller.common.AbstractFunctionalActionWithoutViewFactoryTest#verifyModelAndView()
     */
    @Override
    @After
    public void verifyModelAndView() throws Exception {
        UrlModelAndView modelAndView = (UrlModelAndView) modelAndViewMatcher.getModelAndView();
        Assert.assertNotNull(modelAndView.getControllerAction());
        Assert.assertNotNull(modelAndView.getUserSessionDTO());        
        Assert.assertEquals(UrlModelAndView.UrlViewSpecification.UrlView, modelAndView.getUrlViewSpecification());
        Assert.assertEquals(UrlModelAndView.UrlViewSpecification.UrlView.toString(), modelAndView.getViewSpecificationDescription());
        Assert.assertNotNull(modelAndView.getTitle());
        Assert.assertNotNull(modelAndView.getUrl());
    }

}
