/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.agent.sweden;

import java.util.Date;
import java.util.List;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;

import com.gargoylesoftware.htmlunit.WebClient;
import com.hack23.cia.model.sweden.impl.CommitteeReport;
import com.hack23.cia.service.impl.common.AbstractUnitJmockTest;
import com.hack23.cia.testfoundation.TestInstance;

/**
 * The Class CommitteeReportAgentImplTest.
 */
public class CommitteeReportAgentImplTest extends AbstractUnitJmockTest {

    /** The committee report agent impl. */
    private CommitteeReportAgentImpl committeeReportAgentImpl;

	/** The web client. */
	private WebClient webClient = new WebClient();

    /**
     * Before test.
     */
    @Before
    public final void beforeTest() {
    	webClient.setActiveXNative(false);
    	webClient.setJavaScriptEnabled(false);
    	webClient.setRedirectEnabled(false);
    	
    	committeeReportAgentImpl = new CommitteeReportAgentImpl(webClient);
    }

    /**
     * Gets the current list successfull test.
     *
     * @return the current list successfull test
     */
    @Test
    public final void getCurrentListSuccessfullTest() {
        new TestInstance() {

            private List<CommitteeReport> currentList;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(currentList);                
            }

            @Override
            public void run() {
            	try {
					currentList = committeeReportAgentImpl.getCurrentList();
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            }

        }.executeTestPhases();
    }
    
    /**
     * Gets the decided date if any successfull test.
     *
     * @return the decided date if any successfull test
     */
    @Test
    public final void getDecidedDateIfAnySuccessfullTest() {
        new TestInstance() {

            private CommitteeReport commiteeReport;
			private Date decidedDate;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(decidedDate);                
            }

            @Override
            public void run() {
            	try {
					decidedDate = committeeReportAgentImpl.getDecidedDateIfAny(commiteeReport);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	commiteeReport = new CommitteeReport();
            	commiteeReport.setHref("http://www.riksdagen.se/webbnav/?nid=3120&doktyp=betankande&bet=2008%2f09%3aUU15");
            }

        }.executeTestPhases();
    }
}
