/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.service.impl.agent.sweden;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;

import com.gargoylesoftware.htmlunit.WebClient;
import com.hack23.cia.model.sweden.impl.ParliamentMember;
import com.hack23.cia.service.impl.common.AbstractUnitJmockTest;
import com.hack23.cia.testfoundation.TestInstance;

/**
 * The Class ParliamentMemberAgentImplTest.
 */
public class ParliamentMemberAgentImplTest extends AbstractUnitJmockTest {

    /** The parliament member agent impl. */
    private ParliamentMemberAgentImpl parliamentMemberAgentImpl;

	/** The web client. */
	private WebClient webClient = new WebClient();

    /**
     * Before test.
     */
    @Before
    public final void beforeTest() {
    	webClient.setActiveXNative(false);
    	webClient.setJavaScriptEnabled(false);
    	webClient.setRedirectEnabled(false);
    	
    	parliamentMemberAgentImpl = new ParliamentMemberAgentImpl(webClient);
    	parliamentMemberAgentImpl.initData();
    }

    /**
     * Gets the english wiki href successfull test.
     *
     * @return the english wiki href successfull test
     */
    @Test
    public final void getEnglishWikiHrefSuccessfullTest() {
        new TestInstance() {

            private String englishWikiHref;
			private ParliamentMember parliamentMember;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(englishWikiHref);                
            }

            @Override
            public void run() {
            	try {
					englishWikiHref = parliamentMemberAgentImpl.getEnglishWikiHref(parliamentMember);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	parliamentMember = new ParliamentMember();
            	parliamentMember.setName("Sahlin, Mona");
            }

        }.executeTestPhases();
    }
    
    /**
     * Gets the href successfull test.
     *
     * @return the href successfull test
     */
    @Test
    public final void getHrefSuccessfullTest() {
        new TestInstance() {

            private String href;
			private ParliamentMember parliamentMember;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(href);                
            }

            @Override
            public void run() {
            	try {
					href = parliamentMemberAgentImpl.getHref(parliamentMember);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	parliamentMember = new ParliamentMember();
            	parliamentMember.setName("Sahlin, Mona");
            }

        }.executeTestPhases();
    }
    
    /**
     * Gets the wiki href successfull test.
     *
     * @return the wiki href successfull test
     */
    //@Test
    //IGnore
    public final void getWikiHrefSuccessfullTest() {
        new TestInstance() {

            private ParliamentMember parliamentMember;
			private String wikiHref;

			@Override
            public void assertPostcondition() {
                context.assertIsSatisfied();
                Assert.assertNotNull(wikiHref);                
            }

            @Override
            public void run() {
            	try {
					wikiHref = parliamentMemberAgentImpl.getWikiHref(parliamentMember);
				} catch (Exception e) {
					Assert.fail("Not expected Exception: " + e.getMessage());
				}
            }

            @Override
            public void setupExpectations() {
            	parliamentMember = new ParliamentMember();
            	parliamentMember.setName("Sahlin, Mona");
            }

        }.executeTestPhases();
    }

}
