/*
Copyright 2010 James Pether Sörling Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. 
	$Id
*/

package com.hack23.cia.systemintegrationtest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.jetty.server.Connector;
import org.eclipse.jetty.server.Server;
import org.eclipse.jetty.server.nio.SelectChannelConnector;
import org.eclipse.jetty.webapp.WebAppContext;

import com.hack23.cia.model.application.dto.common.ApplicationProperties;

/**
 * The Class CitizenIntelligenceAgencyServer.
 */
public class CitizenIntelligenceAgencyServer {

    /** The application properties. */
    private static ApplicationProperties applicationProperties = new ApplicationProperties();

    /** The Constant LOGGER. */
    private static final Log LOGGER = LogFactory
            .getLog(CitizenIntelligenceAgencyServer.class);

    /** The Constant PORT. */
    private static final int PORT = 8080; 
    
    /** The Constant TARGET_CITIZEN_INTELLIGENCE_AGENCY_1_0_SNAPSHOT. */
    private static final String TARGET_CITIZEN_INTELLIGENCE_AGENCY_1_0_SNAPSHOT = "target/citizen-intelligence-agency-" + applicationProperties.getVersion(); //$NON-NLS-1$

    /**
     * The main method.
     *
     * @param args the arguments
     */
    public static void main(final String[] args) {
        final CitizenIntelligenceAgencyServer testServer = new CitizenIntelligenceAgencyServer();
        try {
            testServer.init();
            testServer.start();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /** The initialised. */
    private boolean initialised = false;

    /** The server. */
    private final Server server = new Server();

    /**
     * Inits the.
     *
     * @throws Exception the exception
     */
    public final void init() throws Exception {
        initialised = true;
        Connector connector = new SelectChannelConnector();
        connector.setPort(PORT);
        server.setConnectors(new Connector[] { connector });
        server.setHandler(new WebAppContext(
                TARGET_CITIZEN_INTELLIGENCE_AGENCY_1_0_SNAPSHOT, "/"));
    }

    /**
     * Start.
     *
     * @throws Exception the exception
     */
    public final void start() throws Exception {
        if (!initialised) {
            LOGGER.info("Exiting init not called before start"); //$NON-NLS-1$
            System.exit(-1);
        }

        try {
            server.start();
        } catch (Exception e) {
        	LOGGER.fatal("Problem starting server",e);
        }
    }

    /**
     * Stop.
     *
     * @throws Exception the exception
     */
    public final void stop() throws Exception {
        server.stop();
    }
}
